import { debounce } from 'lodash-wechat';
import { useTaroMemo } from '@tarojs/taro';
import useLatest from '../useLatest';
import useUnmount from '../useUnmount';

function useDebounceFn(fn, options) {
  var _options$wait;

  if (process.env.NODE_ENV === 'development') {
    if (typeof fn !== 'function') {
      console.error("useDebounceFn expected parameter is a function, got " + typeof fn);
    }
  }

  var fnRef = useLatest(fn);
  var wait = (_options$wait = options == null ? void 0 : options.wait) != null ? _options$wait : 1000;
  var debounced = useTaroMemo(function () {
    return (// @ts-ignore
      debounce(function () {
        return fnRef.current.apply(fnRef, arguments);
      }, wait, options)
    );
  }, []);
  useUnmount(function () {
    // @ts-ignore
    debounced.cancel();
  });
  return {
    run: debounced,
    // @ts-ignore
    cancel: debounced.cancel,
    // @ts-ignore
    flush: debounced.flush
  };
}

export default useDebounceFn;