import { useTaroMemo, useTaroRef } from '@tarojs/taro';
import { isFunction } from '@taro-hooks/shared';

function useMemoizedFn(fn) {
  if (process.env.NODE_ENV === 'development') {
    if (!isFunction(fn)) {
      console.error("useMemoizedFn expected parameter is a function, got " + typeof fn);
    }
  }

  var fnRef = useTaroRef(fn); // why not write `fnRef.current = fn`?
  // https://github.com/alibaba/hooks/issues/728

  fnRef.current = useTaroMemo(function () {
    return fn;
  }, [fn]);
  var memoizedFn = useTaroRef();

  if (!memoizedFn.current) {
    memoizedFn.current = function () {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return fnRef.current.apply(this, args);
    };
  }

  return memoizedFn.current;
}

export default useMemoizedFn;