import { throttle } from 'lodash-wechat';
import { useTaroMemo } from '@tarojs/taro';
import useLatest from '../useLatest';
import useUnmount from '../useUnmount';

function useThrottleFn(fn, options) {
  var _options$wait;

  if (process.env.NODE_ENV === 'development') {
    if (typeof fn !== 'function') {
      console.error("useThrottleFn expected parameter is a function, got " + typeof fn);
    }
  }

  var fnRef = useLatest(fn);
  var wait = (_options$wait = options == null ? void 0 : options.wait) != null ? _options$wait : 1000;
  var throttled = useTaroMemo(function () {
    return (// @ts-ignore
      throttle(function () {
        return fnRef.current.apply(fnRef, arguments);
      }, wait, options)
    );
  }, []);
  useUnmount(function () {
    // @ts-ignore
    throttled.cancel();
  });
  return {
    run: throttled,
    // @ts-ignore
    cancel: throttled.cancel,
    // @ts-ignore
    flush: throttled.flush
  };
}

export default useThrottleFn;